package com.ruoyi.dxp.service;

import java.util.List;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.dxp.domain.UserApply;
import com.ruoyi.dxp.dto.AuditDto;
import com.ruoyi.dxp.dto.customer.CompanyRegisterParam;

/**
 * 企业用户申请Service接口
 * 
 * @author jy
 * @date 2022-12-05
 */
public interface IUserApplyService 
{
    /**
     * 查询企业用户申请
     * 
     * @param id 企业用户申请主键
     * @return 企业用户申请
     */
    public UserApply selectUserApplyById(Long id);

    /**
     * 查询企业用户申请列表
     * 
     * @param userApply 企业用户申请
     * @return 企业用户申请集合
     */
    public List<UserApply> selectUserApplyList(UserApply userApply);

    /**
     * 新增企业用户申请
     * 
     * @param userApply 企业用户申请
     * @return 结果
     */
    public int insertUserApply(UserApply userApply);

    /**
     * 修改企业用户申请
     * 
     * @param userApply 企业用户申请
     * @return 结果
     */
    public int updateUserApply(UserApply userApply);

    /**
     * 批量删除企业用户申请
     * 
     * @param ids 需要删除的企业用户申请主键集合
     * @return 结果
     */
    public int deleteUserApplyByIds(Long[] ids);

    /**
     * 删除企业用户申请信息
     * 
     * @param id 企业用户申请主键
     * @return 结果
     */
    public int deleteUserApplyById(Long id);

    /**
     * 注册
     * @param apply 注册对象
     * @return 注册结果
     */
    public AjaxResult register(CompanyRegisterParam apply);

    /**
     * 审核
     * @param auditDto 审核对象
     * @return 审核结果
     */
    public AjaxResult audit(AuditDto auditDto);
}
